@@ -6,7 +6,13 @@ extern int BOXATTR;
 extern int ACTIVEATTR;
 extern int BARSTDATTR;
 extern int BARHIGHATTR;
+extern int DLGTEXTATTR;
+extern int DLGHIGHATTR;
+extern int DLGBOXATTR;
 extern int DESCATTR;
+extern int STATUSBARATTR;
+extern int IPSTATATTR;
+extern int IPSTATLABELATTR;
 extern int PTRATTR;
 extern int FIELDATTR;
 extern int ERRBOXATTR;
