@@ -33,7 +33,13 @@ int BOXATTR;
 int ACTIVEATTR;
 int BARSTDATTR;
 int BARHIGHATTR;
+int DLGTEXTATTR;
+int DLGBOXATTR;
+int DLGHIGHATTR;
 int DESCATTR;
+int STATUSBARATTR;
+int IPSTATLABELATTR;
+int IPSTATATTR;
 int PTRATTR;
 int FIELDATTR;
 int ERRBOXATTR;
@@ -54,13 +60,14 @@ void draw_desktop(void)
 {
     int row;			/* counter for desktop construction */
     char sp_buf[10];
-
-    attrset(STDATTR);
-    move(0, 0);
+    
     sprintf(sp_buf, "%%%dc", COLS);
+    scrollok(stdscr, 0);
+    attrset(STATUSBARATTR);
+    move(0, 0);
     printw(sp_buf, ' ');	/* these two print the top n' bottom */
     move(LINES - 1, 0);
-    printw(sp_buf, ' ');	/* lines */
+    printw(sp_buf, 'a');	/* lines */
 
     attrset(FIELDATTR);
 
@@ -134,7 +141,7 @@ void about()
     mvwprintw(win, 2, 2, "An IP Network Statistics Utility");
     mvwprintw(win, 3, 2, "Version %s", VERSION);
     mvwprintw(win, 5, 2, "Written by Gerard Paul Java");
-    mvwprintw(win, 6, 2, "Copyright (c) Gerard Paul Java 1997-2000");
+    mvwprintw(win, 6, 2, "Copyright (c) Gerard Paul Java 1997-2001");
     mvwprintw(win, 8, 2, "This program is distributed under the terms of");
     mvwprintw(win, 9, 2, "the GNU General Public License Version 2 or");
     mvwprintw(win, 10, 2, "any later version. See the included COPYING");
@@ -170,63 +177,64 @@ void printipcerr()
     mvprintw(0, 68, "  IPC Error ");
 }
 
-void printkeyhelp(char *keytext, char *desc, WINDOW * win)
+void printkeyhelp(char *keytext, char *desc, WINDOW * win,
+                  int highattr, int textattr)
 {
-    wattrset(win, HIGHATTR);
+    wattrset(win, highattr);
     wprintw(win, "%s", keytext);
-    wattrset(win, STDATTR);
+    wattrset(win, textattr);
     wprintw(win, "%s", desc);
 }
 
 void stdkeyhelp(WINDOW * win)
 {
-    printkeyhelp("Enter", "-accept  ", win);
-    printkeyhelp("Ctrl+X", "-cancel", win);
+    printkeyhelp("Enter", "-accept  ", win, DLGHIGHATTR, DLGTEXTATTR);
+    printkeyhelp("Ctrl+X", "-cancel", win, DLGHIGHATTR, DLGTEXTATTR);
 }
 
 void sortkeyhelp(void)
 {
-    printkeyhelp("S", "-sort  ", stdscr);
+    printkeyhelp("S", "-sort  ", stdscr, HIGHATTR, STATUSBARATTR);
 }
 
 void stdexitkeyhelp(void)
 {
-    printkeyhelp("X", "-exit", stdscr);
+    printkeyhelp("X", "-exit", stdscr, HIGHATTR, STATUSBARATTR);
     coloreol(stdscr);
 }
 
 void scrollkeyhelp(void)
 {
-    printkeyhelp("Up/Down/PgUp/PgDn", "-scroll window  ", stdscr);
+    printkeyhelp("Up/Down/PgUp/PgDn", "-scroll window  ", stdscr, HIGHATTR, STDATTR);
 }
 
 void menukeyhelp(void)
 {
     move(LINES - 1, 1);
-    printkeyhelp("Up/Down", "-Move selector  ", stdscr);
-    printkeyhelp("Enter", "-execute", stdscr);
+    printkeyhelp("Up/Down", "-Move selector  ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("Enter", "-execute", stdscr, HIGHATTR, STATUSBARATTR);
     coloreol(stdscr);
 }
 
 void listkeyhelp()
 {
     move(LINES - 1, 1);
-    printkeyhelp("Up/Down", "-move pointer  ", stdscr);
-    printkeyhelp("Enter", "-select  ", stdscr);
+    printkeyhelp("Up/Down", "-move pointer  ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("Enter", "-select  ", stdscr, HIGHATTR, STATUSBARATTR);
     stdexitkeyhelp();
 }
 
 void tabkeyhelp(WINDOW * win)
 {
-    printkeyhelp("Tab", "-next field  ", win);
+    printkeyhelp("Tab", "-next field  ", win, DLGHIGHATTR, DLGTEXTATTR);
 }
 
 void indicate(char *message)
 {
     char sp_buf[10];
-    attrset(STDATTR);
-    sprintf(sp_buf, "%%%dc", COLS - 1);
-    mvprintw(LINES - 1, 1, sp_buf, ' ');
+    attrset(STATUSBARATTR);
+    sprintf(sp_buf, "%%%dc", COLS);
+    mvprintw(LINES - 1, 0, sp_buf, ' ');
     mvprintw(LINES - 1, 1, message);
     refresh();
 }
@@ -310,6 +318,12 @@ void standardcolors(int color)
 	BARSTDATTR = COLOR_PAIR(15) | A_BOLD;
 	BARHIGHATTR = COLOR_PAIR(11) | A_BOLD;
 	DESCATTR = COLOR_PAIR(2);
+	DLGTEXTATTR = COLOR_PAIR(2);
+	DLGBOXATTR = COLOR_PAIR(6);
+	DLGHIGHATTR = COLOR_PAIR(12);
+	STATUSBARATTR = STDATTR;
+	IPSTATLABELATTR = COLOR_PAIR(2);
+	IPSTATATTR = COLOR_PAIR(12);
 	PTRATTR = COLOR_PAIR(10) | A_BOLD;
 	FIELDATTR = COLOR_PAIR(1);
 	ERRBOXATTR = COLOR_PAIR(5) | A_BOLD;
@@ -330,8 +344,14 @@ void standardcolors(int color)
 	BARSTDATTR = A_REVERSE;
 	BARHIGHATTR = A_BOLD;
 	DESCATTR = A_NORMAL;
+        DLGBOXATTR = A_REVERSE;
+        DLGTEXTATTR = A_REVERSE;
+        DLGHIGHATTR = A_BOLD;
+        STATUSBARATTR = A_REVERSE;
+        IPSTATLABELATTR = A_REVERSE;
+        IPSTATATTR = A_STANDOUT;
 	PTRATTR = A_BOLD;
-	FIELDATTR = A_REVERSE;
+	FIELDATTR = A_BOLD;
 	ERRBOXATTR = A_BOLD;
 	ERRTXTATTR = A_NORMAL;
 	OSPFATTR = A_REVERSE;
