@@ -5,13 +5,12 @@
 
  */
 
-#include "version.h"
-
 void draw_desktop(void);
 void colorwin(WINDOW * win);
 void printnomem();
 void printipcerr();
-void printkeyhelp(char *keytext, char *desc, WINDOW * win);
+void printkeyhelp(char *keytext, char *desc, WINDOW * win,
+                  int highattr, int textattr);
 void stdkeyhelp(WINDOW * win);
 void sortkeyhelp(void);
 void tabkeyhelp(WINDOW * win);
