@@ -1,4 +1,15 @@
-#include"getpath.h"
+/*
+ * dirs.h - directory and file definitions used by IPTraf
+ *
+ * You may change these directories to suit your needs, BUT:
+ *
+ *   1. Some directories contain files that IPTraf may erase, see LOCKDIR
+ *   2. The temporary file creation methods are NOT SAFE FOR USE ON WORLD
+ *      WRITABLE DIRECTORIES.  Do not define any of these directories to
+ *      be any world-writable directory, such as /tmp or /var/tmp.
+ */
+
+#include "getpath.h"
 
 /*
  * IPTraf working file and directory definitions
@@ -26,6 +37,17 @@
 #define EXECDIR		"/usr/local/bin"
 #endif
 
+/*
+ * Lock directory.
+ * 
+ * !!!!!!! WARNING !!!!!!!!
+ * DO NOT LET THIS REFER TO AN EXISTING/SYSTEM DIRECTORY!!!!  THE LOCK
+ * OVERRIDE (iptraf -f) WILL ERASE ALL FILES HERE!
+ */
+ 
+#ifndef LOCKDIR
+#define LOCKDIR		"/var/run/iptraf"
+#endif
 
 /***
  *** Directory environment variables.  Overrides built in definitions.
@@ -55,26 +77,29 @@
  *  file is used to restrict configuration to only the first instance.
  */
 
-#define IPTIDFILE	get_path(T_WORKDIR, "iptraf.tag")
+#define IPTIDFILE	get_path(T_LOCKDIR, "iptraf.tag")
 
 /*
- * The IPTraf facility identification files.  These are used to tag each
- * individual facility, allowing only one of each kind running at any one
- * time systemwide.
+ * The IPTraf facility identification files.  These are used to identify which
+ * facilities are running, allowing only one instance any of them to run
+ * on a network interface.
  */
  
-#define IPMONIDFILE	get_path(T_WORKDIR, "ipmon.tag")
-#define GSTATIDFILE	get_path(T_WORKDIR, "genstat.tag")
-#define DSTATIDFILE	get_path(T_WORKDIR, "detstat.tag")
-#define TCPUDPIDFILE	get_path(T_WORKDIR, "tcpudp.tag")
-#define LANMONIDFILE	get_path(T_WORKDIR, "lanmon.tag")
-#define IPHOSTSIDFILE	get_path(T_WORKDIR, "iphosts.tag")
-#define TCPFLTIDFILE	get_path(T_WORKDIR, "tcpfltchg.tag")
-#define UDPFLTIDFILE	get_path(T_WORKDIR, "udpfltchg.tag")
-#define OTHFLTIDFILE	get_path(T_WORKDIR, "othfltchg.tag")
-#define PKTSIZEIDFILE	get_path(T_WORKDIR, "packetsize.tag")
-#define PROCCOUNTFILE	get_path(T_WORKDIR, "iptrafprocesscount.dat")
-#define PROMISCLISTFILE get_path(T_WORKDIR, "promisclist.tmp")
+#define IPMONIDFILE		get_path(T_LOCKDIR, "iptraf-ipmon.tag")
+#define GSTATIDFILE		get_path(T_LOCKDIR, "iptraf-genstat.tag")
+#define DSTATIDFILE		get_path(T_LOCKDIR, "iptraf-detstat.tag")
+#define TCPUDPIDFILE		get_path(T_LOCKDIR, "iptraf-tcpudp.tag")
+#define LANMONIDFILE		get_path(T_LOCKDIR, "iptraf-lanmon.tag")
+#define IPHOSTSIDFILE		get_path(T_LOCKDIR, "iptraf-iphosts.tag")
+#define TCPFLTIDFILE		get_path(T_LOCKDIR, "iptraf-tcpfltchg.tag")
+#define UDPFLTIDFILE		get_path(T_LOCKDIR, "iptraf-udpfltchg.tag")
+#define OTHFLTIDFILE		get_path(T_LOCKDIR, "iptraf-othfltchg.tag")
+#define PKTSIZEIDFILE		get_path(T_LOCKDIR, "iptraf-packetsize.tag")
+#define PROCCOUNTFILE		get_path(T_LOCKDIR, "iptraf-processcount.dat")
+#define ITRAFMONCOUNTFILE 	get_path(T_LOCKDIR, "iptraf-itrafmoncount.dat")
+#define LANMONCOUNTFILE		get_path(T_LOCKDIR, "iptraf-lanmoncount.dat")
+#define PROMISCLISTFILE 	get_path(T_WORKDIR, "promisclist.tmp")
+
 /*
  * The TCP filter list file
  */
@@ -103,12 +128,12 @@
  * The IPTraf log files
  */
  
-#define IPMONLOG	get_path(T_LOGDIR, "ip_traffic.log")
+#define IPMONLOG	get_path(T_LOGDIR, "ip_traffic")
 #define GSTATLOG	get_path(T_LOGDIR, "iface_stats_general.log")
-#define DSTATLOG	get_path(T_LOGDIR, "iface_stats_detailed.log")
-#define TCPUDPLOG	get_path(T_LOGDIR, "tcp_udp_services.log")
-#define LANLOG		get_path(T_LOGDIR, "lan_statistics.log")
-#define PKTSIZELOG	get_path(T_LOGDIR, "packet_size.log")
+#define DSTATLOG	get_path(T_LOGDIR, "iface_stats_detailed")
+#define TCPUDPLOG	get_path(T_LOGDIR, "tcp_udp_services")
+#define LANLOG		get_path(T_LOGDIR, "lan_statistics")
+#define PKTSIZELOG	get_path(T_LOGDIR, "packet_size")
 #define DAEMONLOG	get_path(T_LOGDIR, "daemon.log")
 /*
  * The additional TCP/UDP ports file
