@@ -17,6 +17,6 @@ void servmon(char *iface, struct porttab *ports, const struct OPTIONS *options,
 void ip_host_breakdown(struct OPTIONS *options, char *iface);
 void hostmon(const struct OPTIONS *options, int facilitytime, char *ifptr);
 void ethdescmgr(void);
-void setoptions(struct OPTIONS *options, struct porttab **ports, int is_first_instance);
+void setoptions(struct OPTIONS *options, struct porttab **ports);
 void loadoptions(struct OPTIONS *options);
 void saveoptions(struct OPTIONS *options);
