@@ -122,11 +122,11 @@ void modify_host_parameters(unsigned int protocol, struct filterlist *fl)
     colorwin(win);
 
     move(LINES - 1, 1);
-    printkeyhelp("Up/Down", "-move ptr ", stdscr);
-    printkeyhelp("I", "-insert entry ", stdscr);
-    printkeyhelp("A", "-append to list ", stdscr);
-    printkeyhelp("D", "-delete entry ", stdscr);
-    printkeyhelp("X/Ctrl+X", "-exit", stdscr);
+    printkeyhelp("Up/Down", "-move ptr ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("I", "-insert entry ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("A", "-append to list ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("D", "-delete entry ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("X/Ctrl+X", "-exit", stdscr, HIGHATTR, STATUSBARATTR);
 
     update_panels();
     doupdate();
