@@ -148,10 +148,10 @@ void get_filter_description(char *description, int *aborted,
     dlgwintop = (LINES - 9) / 2;
     dlgwin = newwin(7, 42, dlgwintop, (COLS - 42) / 2 - 10);
     dlgpanel = new_panel(dlgwin);
-    wattrset(dlgwin, BOXATTR);
+    wattrset(dlgwin, DLGBOXATTR);
     colorwin(dlgwin);
     box(dlgwin, ACS_VLINE, ACS_HLINE);
-    wattrset(dlgwin, STDATTR);
+    wattrset(dlgwin, DLGTEXTATTR);
     wmove(dlgwin, 2, 2);
     wprintw(dlgwin, "Enter a description for this filter");
     wmove(dlgwin, 5, 2);
