@@ -80,7 +80,7 @@ extern void show_sort_statwin(WINDOW **win, PANEL **panel);
 void rotate_lanlog()
 {
     rotate_flag = 1;
-    strcpy(target_logname, LANLOG);
+    strcpy(target_logname, current_logfile);
     signal(SIGUSR1, rotate_lanlog);
 }
 
@@ -462,26 +462,26 @@ void show_hostsort_keywin(WINDOW ** win, PANEL ** panel)
     *win = newwin(13, 35, (LINES - 10) / 2, COLS - 40);
     *panel = new_panel(*win);
 
-    wattrset(*win, BOXATTR);
+    wattrset(*win, DLGBOXATTR);
     colorwin(*win);
     box(*win, ACS_VLINE, ACS_HLINE);
 
-    wattrset(*win, STDATTR);
+    wattrset(*win, DLGTEXTATTR);
     mvwprintw(*win, 2, 2, "Select display field to sort by");
     wmove(*win, 4, 2);
-    printkeyhelp("P", " - total packets in", *win);
+    printkeyhelp("P", " - total packets in", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 5, 2);
-    printkeyhelp("I", " - IP packets in", *win);
+    printkeyhelp("I", " - IP packets in", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 6, 2);
-    printkeyhelp("B", " - total bytes in", *win);
+    printkeyhelp("B", " - total bytes in", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 7, 2);
-    printkeyhelp("K", " - total packets out", *win);
+    printkeyhelp("K", " - total packets out", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 8, 2);
-    printkeyhelp("O", " - IP packets out", *win);
+    printkeyhelp("O", " - IP packets out", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 9, 2);
-    printkeyhelp("Y", " - total bytes out", *win);
+    printkeyhelp("Y", " - total bytes out", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 10, 2);
-    printkeyhelp("Any other key", " - cancel sort", *win);
+    printkeyhelp("Any other key", " - cancel sort", *win, DLGHIGHATTR, DLGTEXTATTR);
     update_panels();
     doupdate();
 }
@@ -665,27 +665,29 @@ void hostmon(const struct OPTIONS *options, int facilitytime, char *ifptr)
     WINDOW *sortwin;
     PANEL *sortpanel;
     int keymode = 0;
-
+    
+    int instance_id;
+    char msgstring[80];
+    
     struct promisc_states *promisc_list;
 
-    if (!facility_active(LANMONIDFILE))
-	mark_facility(LANMONIDFILE, "LAN monitor");
+    if (!facility_active(LANMONIDFILE, ifptr))
+	mark_facility(LANMONIDFILE, "LAN monitor", ifptr);
     else {
-	write_error
-	    ("LAN station monitor already active in another process",
-	     daemonized);
+	snprintf(msgstring, 80, "LAN station monitor already running on %s", gen_iface_msg(ifptr));
+	write_error(msgstring, daemonized);
 	return;
     }
 
     if (ifptr != NULL) {
 	if (!iface_supported(ifptr)) {
 	    err_iface_unsupported();
-	    unmark_facility(LANMONIDFILE);
+	    unmark_facility(LANMONIDFILE, ifptr);
 	    return;
 	}
 	if (!iface_up(ifptr)) {
 	    err_iface_down();
-	    unmark_facility(LANMONIDFILE);
+	    unmark_facility(LANMONIDFILE, ifptr);
 	    return;
 	}
     }
@@ -693,7 +695,7 @@ void hostmon(const struct OPTIONS *options, int facilitytime, char *ifptr)
     open_socket(&fd);
 
     if (fd < 0) {
-	unmark_facility(LANMONIDFILE);
+	unmark_facility(LANMONIDFILE, ifptr);
 	return;
     }
 
@@ -704,16 +706,26 @@ void hostmon(const struct OPTIONS *options, int facilitytime, char *ifptr)
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(1);
-
+    adjust_instance_count(PROCCOUNTFILE, 1);
+    instance_id = adjust_instance_count(LANMONCOUNTFILE, 1);
+    strncpy(active_facility_countfile, LANMONCOUNTFILE, 64);
+    
     hostmonhelp();
 
     initethtab(&table, options->actmode);
     loaddesclist(&elist, LINK_ETHERNET);
     loaddesclist(&flist, LINK_FDDI);
-
+    
     if (logging) {
-	opentlog(&logfile, LANLOG);
+        if (strcmp(current_logfile, "") == 0)
+            strncpy(current_logfile, gen_instance_logname(LANLOG, instance_id), 80);
+	
+	if (!daemonized)
+	    input_logfile(current_logfile, &logging);
+    }
+    
+    if (logging) {
+	opentlog(&logfile, current_logfile);
 
 	if (logfile == NULL)
 	    logging = 0;
@@ -882,7 +894,8 @@ void hostmon(const struct OPTIONS *options, int facilitytime, char *ifptr)
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(-1);
+    adjust_instance_count(PROCCOUNTFILE, -1);
+    adjust_instance_count(LANMONCOUNTFILE, -1);
 
     if (logging) {
 	signal(SIGUSR1, SIG_DFL);
@@ -903,5 +916,6 @@ void hostmon(const struct OPTIONS *options, int facilitytime, char *ifptr)
     destroyethtab(&table);
     destroydesclist(&elist);
     destroydesclist(&flist);
-    unmark_facility(LANMONIDFILE);
+    unmark_facility(LANMONIDFILE, ifptr);
+    strcpy(current_logfile, "");
 }
