@@ -143,3 +143,15 @@ void isdn_iface_check(int *fd, char *ifname)
 	    *fd = open("/dev/isdnctrl", O_RDWR);
     }
 }
+
+char *gen_iface_msg(char *ifptr)
+{
+    static char if_msg[20];
+    
+    if (ifptr == NULL)
+        strcpy(if_msg, "all interfaces");
+    else
+        strncpy(if_msg, ifptr, 20);
+        
+    return if_msg;
+}
