@@ -86,7 +86,7 @@ void rotate_gstat_log()
 void rotate_dstat_log()
 {
     rotate_flag = 1;
-    strcpy(target_logname, DSTATLOG);
+    strcpy(target_logname, current_logfile);
     signal(SIGUSR1, rotate_dstat_log);
 }
 
@@ -444,8 +444,8 @@ void ifstats(const struct OPTIONS *options, int facilitytime)
 
     struct promisc_states *promisc_list;
 
-    if (!facility_active(GSTATIDFILE))
-	mark_facility(GSTATIDFILE, "general interface statistics");
+    if (!facility_active(GSTATIDFILE, ""))
+	mark_facility(GSTATIDFILE, "general interface statistics", "");
     else {
 	write_error
 	    ("General interface stats already active in another process",
@@ -456,7 +456,7 @@ void ifstats(const struct OPTIONS *options, int facilitytime)
     open_socket(&fd);
 
     if (fd < 0) {
-	unmark_facility(GSTATIDFILE);
+	unmark_facility(GSTATIDFILE, "");
 	return;
     }
     initiftab(&table);
@@ -468,7 +468,17 @@ void ifstats(const struct OPTIONS *options, int facilitytime)
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(1);
+    adjust_instance_count(PROCCOUNTFILE, 1);
+    active_facility_countfile[0] = '\0';
+    
+    if (logging) {
+        if (strcmp(current_logfile, "") == 0)
+            strcpy(current_logfile, GSTATLOG);
+            
+        if (!daemonized)
+            input_logfile(current_logfile, &logging);
+    }
+        
     if (logging) {
 	opentlog(&logfile, GSTATLOG);
 
@@ -607,7 +617,7 @@ void ifstats(const struct OPTIONS *options, int facilitytime)
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(-1);
+    adjust_instance_count(PROCCOUNTFILE, -1);
 
     del_panel(table.statpanel);
     delwin(table.statwin);
@@ -626,13 +636,13 @@ void ifstats(const struct OPTIONS *options, int facilitytime)
     }
     destroyiflist(table.head);
     destroy_isdn_table(&isdntable);
-    unmark_facility(GSTATIDFILE);
+    unmark_facility(GSTATIDFILE, "");
+    strcpy(current_logfile, "");
 }
 
 
 void printdetlabels(WINDOW * win, struct iftotals *totals)
 {
-    /* TODO? : Adjust values for !80 column displays */
     wattrset(win, BOXATTR);
     mvwprintw(win, 2, 14,
 	      "  Total      Total    Incoming   Incoming    Outgoing   Outgoing");
@@ -650,8 +660,9 @@ void printdetlabels(WINDOW * win, struct iftotals *totals)
     mvwprintw(win, 16, 2, "Incoming rates:");
     mvwprintw(win, 19, 2, "Outgoing rates:");
 
-    wmove(win, 16, 45);
-    wprintw(win, "IP checksum errors:");
+    mvwprintw(win, 13, 45, "Broadcast packets:");
+    mvwprintw(win, 14, 45, "Broadcast bytes:");
+    mvwprintw(win, 18, 45, "IP checksum errors:");
 
     update_panels();
     doupdate();
@@ -713,10 +724,17 @@ void printdetails(struct iftotals *totals, WINDOW * win)
     printstatrow(win, 10, totals->noniptotal, totals->nonipbtotal,
 		 totals->noniptotal_in, totals->nonipbtotal_in,
 		 totals->noniptotal_out, totals->nonipbtotal_out);
+    
+    /* Broadcast totals */
+    
+    wmove(win, 13, 67);
+    printlargenum(totals->bcast, win);
+    wmove(win, 14, 67);
+    printlargenum(totals->bcastbytes, win);
+    
     /* Bad packet count */
 
-    wmove(win, 16, 67);
-    wprintw(win, "%8lu", totals->badtotal);
+    mvwprintw(win, 18, 68, "%8lu", totals->badtotal);
 }
 
 
@@ -742,11 +760,12 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
     unsigned short linktype;
 
     int fd;
-    FILE *logfile = NULL;
     int isdn_fd = -1;
     int br;
     int framelen = 0;
 
+    FILE *logfile = NULL;
+    
     int iphlen;
     int ipck, ipcsum;
     unsigned int iplen = 0;
@@ -788,34 +807,35 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
     char unitstring[7];
 
     struct promisc_states *promisc_list;
+    
+    char err_msg[80];
 
     /*
      * Mark this facility
      */
 
-    if (!facility_active(DSTATIDFILE))
-	mark_facility(DSTATIDFILE, "detailed interface statistics");
+    if (!facility_active(DSTATIDFILE, iface))
+	mark_facility(DSTATIDFILE, "detailed interface statistics", iface);
     else {
-	write_error
-	    ("Detailed interface stats already active in another process",
-	     daemonized);
+        snprintf(err_msg, 80, "Detailed interface stats already monitoring %s", iface);
+	write_error(err_msg, daemonized);
 	return;
     }
 
     open_socket(&fd);
 
     if (fd < 0) {
-	unmark_facility(DSTATIDFILE);
+	unmark_facility(DSTATIDFILE, iface);
 	return;
     }
     if (!iface_supported(iface)) {
 	err_iface_unsupported();
-	unmark_facility(DSTATIDFILE);
+	unmark_facility(DSTATIDFILE, iface);
 	return;
     }
     if (!iface_up(iface)) {
 	err_iface_down();
-	unmark_facility(DSTATIDFILE);
+	unmark_facility(DSTATIDFILE, iface);
 	return;
     }
 
@@ -826,9 +846,9 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(1);
-
-
+    adjust_instance_count(PROCCOUNTFILE, 1);
+    active_facility_countfile[0] = '\0';
+    
     move(LINES - 1, 1);
     stdexitkeyhelp();
     statwin = newwin(LINES - 2, COLS, 1, 0);
@@ -847,7 +867,15 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
     bzero(&totals, sizeof(struct iftotals));
 
     if (logging) {
-	opentlog(&logfile, DSTATLOG);
+        if (strcmp(current_logfile, "") == 0)
+            snprintf(current_logfile, 64, "%s-%s.log", DSTATLOG, iface);
+        
+        if (!daemonized)
+            input_logfile(current_logfile, &logging);
+    }
+        
+    if (logging) {
+	opentlog(&logfile, current_logfile);
 
 	if (logfile == NULL)
 	    logging = 0;
@@ -921,6 +949,11 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
 		spanpkt_in++;
 	    }
 
+	    if (fromaddr.sll_pkttype == PACKET_BROADCAST) {
+	        totals.bcast++;
+	        totals.bcastbytes += br;
+	    }
+	    
 	    spanbr += br;
 	    spanpkt++;
 
@@ -1118,7 +1151,7 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(-1);
+    adjust_instance_count(PROCCOUNTFILE, -1);
 
     if (logging) {
 	signal(SIGUSR1, SIG_DFL);
@@ -1133,7 +1166,8 @@ void detstats(char *iface, const struct OPTIONS *options, int facilitytime)
     }
     del_panel(statpanel);
     delwin(statwin);
-    unmark_facility(DSTATIDFILE);
+    unmark_facility(DSTATIDFILE, iface);
+    strcpy(current_logfile, "");
     destroy_isdn_table(&isdntable);
     update_panels();
     doupdate();
