@@ -2,10 +2,10 @@
 
 IPTraf
 An IP Network Statistics Utility
-Written by Gerard Paul Java <riker@seul.org>, <riker@mozcom.com>
-Copyright (c) Gerard Paul Java 1997-2000
+Written by Gerard Paul Java <riker@seul.org>
+Copyright (c) Gerard Paul Java 1997-2001
    	
-Version 2.3.1
+Version 2.4.0
 Main Module
 
 This software is open-source; you can redistribute it and/or modify
@@ -24,6 +24,7 @@ details.
 
 #include <stdlib.h>
 #include <unistd.h>
+#include <getopt.h>
 #include <curses.h>
 #include <panel.h>
 #include <signal.h>
@@ -32,6 +33,7 @@ details.
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <dirent.h>
 #include "dirs.h"
 #include "deskman.h"
 #include "menurt.h"
@@ -48,35 +50,55 @@ details.
 #include "log.h"
 #include "attrs.h"
 #include "error.h"
+#include "rvnamed.h"
+#include "logvars.h"
+#include "getpath.h"
 
 #define WITHALL 1
 #define WITHOUTALL 0
 
-#define ALLSPEC "all"
+const char *ALLSPEC = "all";
 
 int exitloop = 0;
 int daemonized = 0;
 int facility_running = 0;
 int is_first_instance;
 char active_facility_lockfile[64];
+char active_facility_countfile[64];
 
 extern void about();
 
-void removetags()
+void clearfiles(char *prefix, char *directory)
 {
-    unlink(IPTIDFILE);
-    unlink(IPMONIDFILE);
-    unlink(GSTATIDFILE);
-    unlink(DSTATIDFILE);
-    unlink(TCPUDPIDFILE);
-    unlink(LANMONIDFILE);
-    unlink(TCPFLTIDFILE);
-    unlink(UDPFLTIDFILE);
-    unlink(OTHFLTIDFILE);
-    unlink(PKTSIZEIDFILE);
-    unlink(PROCCOUNTFILE);
+    DIR *dir;
+    struct dirent *dir_entry;
+    char target_name[80];
+    
+    dir = opendir(directory);
+    
+    do {
+        dir_entry = readdir(dir);
+        if (dir_entry != NULL) {
+            if (strncmp(dir_entry->d_name, prefix, strlen(prefix)) == 0) {
+                snprintf(target_name, 80, "%s/%s", directory, dir_entry->d_name);
+                unlink(target_name);
+            }
+        }
+    } while (dir_entry != NULL);
+    
+    closedir(dir);
 }
 
+void removetags(void)
+{
+    clearfiles("iptraf", LOCKDIR);
+}
+
+void remove_sockets(void)
+{
+    clearfiles(SOCKET_PREFIX, WORKDIR);
+}
+           
 /*
  * Handlers for the TERM signal and HUP signals.  There's nothing we can do
  * for the KILL.
@@ -92,15 +114,17 @@ void term_signal_handler(int signo)
 	fprintf(stderr, "IPTraf process %u exiting on signal %d\n\n",
 		getpid(), signo);
 
-    if (strcmp(active_facility_lockfile, "") != 0) {
+    if (active_facility_lockfile[0] != '\0') {
 	unlink(active_facility_lockfile);
-	adjust_process_count(-1);
+	adjust_instance_count(PROCCOUNTFILE, -1);
+	if (active_facility_countfile[0] != '\0')
+	    adjust_instance_count(active_facility_countfile, -1);
     }
 
     if (is_first_instance)
 	unlink(IPTIDFILE);
 
-    exit(0);
+    exit(1);
 }
 
 /* 
@@ -129,15 +153,17 @@ void segvhandler()
     fprintf(stderr, "IPTraf process %u aborting on signal 11.\n\n",
 	    getpid());
 
-    if (strcmp(active_facility_lockfile, "") != 0)
+    if (active_facility_lockfile[0] != '\0')
 	unlink(active_facility_lockfile);
 
     if (is_first_instance)
 	unlink(IPTIDFILE);
 
-    if (strcmp(active_facility_lockfile, "") != 0) {
+    if (active_facility_lockfile[0] != '\0') {
 	unlink(active_facility_lockfile);
-	adjust_process_count(-1);
+	adjust_instance_count(PROCCOUNTFILE, -1);
+	if (active_facility_countfile[0] != '\0')
+	    adjust_instance_count(active_facility_countfile, -1);
     }
 
     exit(2);
@@ -186,16 +212,19 @@ void program_interface(struct OPTIONS *options,
     struct porttab *ports;
 
     draw_desktop();
-    attrset(STDATTR);
-    move(0, 1);
-    printw("IPTraf");
-
+   
+    attrset(STATUSBARATTR);
+    mvprintw(0, 1, "IPTraf");
+    
     loadsavedtcpfilter(&fl, &filtered);
     loadothfilter(&ofilter);
     indicate("");
     loadaddports(&ports);
 
+
     if (opt == 0) {
+        attrset(STATUSBARATTR);
+        mvprintw(LINES - 1, 1, PLATFORM);
 	about();
 
 	initmenu(&menu, 14, 35, (LINES - 14) / 2, (COLS - 35) / 2);
@@ -351,7 +380,7 @@ void commandhelp()
     printf("\nSyntax:\n");
     printf
 	("    iptraf [ -f ] [ { -i iface | -g | -d iface | -s iface | -z iface |\n");
-    printf("           -l iface } [ -B ] [-t timeout ]]\n\n");
+    printf("           -l iface } [ -t timeout ] [ -B [ -L logfile ] ] ]\n\n");
     printf
 	("Issue the iptraf command with no parameters for menu-driven operation.\n");
     printf("These options can also be supplied to the command:\n\n");
@@ -366,20 +395,23 @@ void commandhelp()
     printf
 	("-l iface    - start the LAN station monitor (\"-l all\" for all LAN interfaces)\n");
     printf
-	("-B          - Run in background (use only with one of the above parameters)\n");
+	("-B          - run in background (use only with one of the above parameters)\n");
     printf
 	("-t timeout  - when used with one of the above parameters, tells\n");
     printf
 	("              the facility to run only for the specified number of\n");
     printf("              minutes (timeout)\n");
     printf
-	("-f          - Remove all lock files.  This will allow multiple\n");
+        ("-L logfile  - when used with -B, allows you to specify an alternate\n");
     printf
-	("              instances of facilities in different IPTraf processes.\n");
+        ("              log file.  The log is placed in %s if a path is not\n", LOGDIR);
     printf
-	("              Use with great caution.  Normally used to recover from\n");
-    printf("              an abnormal termination.\n\n");
-    printf("IPTraf %s Copyright (c) Gerard Paul Java 1997-2000\n",
+        ("              specified.\n"); 
+    printf
+	("-f          - Clear all locks and counters.  Use with great caution.\n");
+    printf
+        ("              Normally used to recover from an abnormal termination.\n\n");
+    printf("IPTraf %s Copyright (c) Gerard Paul Java 1997-2001\n",
 	   VERSION);
 }
 
@@ -418,10 +450,6 @@ void mark_first_instance()
 int main(int argc, char **argv)
 {
     struct OPTIONS options;
-    extern char *optarg;
-    extern int optind;
-    extern int opterr;
-    extern int optopt;
     int opt = 0;
     int command = 0;
     char keyparm[12];
@@ -430,13 +458,15 @@ int main(int argc, char **argv)
 #ifndef ALLOWUSERS
     if (getuid() != 0) {
 	fprintf(stderr, "\nIPTraf Version %s\n", VERSION);
-	fprintf(stderr, "Copyright (c) Gerard Paul Java 1997-2000\n\n");
+	fprintf(stderr, "Copyright (c) Gerard Paul Java 1997-2001\n\n");
 	fprintf(stderr,
 		"This program can be run only by the system administrator\n\n");
 	exit(1);
     }
 #endif
 
+    strcpy(current_logfile, "");
+    
     /*
      * Parse command line
      */
@@ -444,13 +474,14 @@ int main(int argc, char **argv)
     if (argc > 1) {
 	do {
 	    opterr = 0;
-	    opt = getopt(argc, argv, "i::gd:s:z:l::hfqt:B");
+	    opt = getopt(argc, argv, "i:gd:s:z:l:hfqt:BL:");
 
 	    if (opt == 'h') {
 		commandhelp();
 		exit(0);
 	    } else if (opt == 'f') {
 		removetags();
+		remove_sockets();
 	    } else if (opt == 't') {
 		facilitytime = atoi(optarg);
 		if (facilitytime == 0) {
@@ -459,6 +490,11 @@ int main(int argc, char **argv)
 		}
 	    } else if (opt == 'B') {
 		daemonized = 1;
+	    } else if (opt == 'L') {
+	        if (strchr(optarg, '/') != NULL)
+	            strncpy(current_logfile, optarg, 80);
+	        else
+	            strncpy(current_logfile, get_path(T_LOGDIR, optarg), 80);
 	    } else if (opt == 'q') {
 		/* -q parameter now ignored, maintained for compatibility */
 	    } else if (opt == '?') {
@@ -515,10 +551,10 @@ int main(int argc, char **argv)
     freopen("/dev/null", "w", stderr);
 #endif
 
-    initscr();
-
     mark_first_instance();
 
+    initscr();
+
     if ((LINES < 24) || (COLS < 80)) {
 	endwin();
 	fprintf(stderr,
@@ -543,6 +579,14 @@ int main(int argc, char **argv)
     curs_set(0);
 #endif
 
+    /*
+     * Set logfilename variable to an empty string in case -L was specified
+     * without -B.
+     */
+     
+    if (!daemonized)
+        strcpy(current_logfile, "");
+        
     program_interface(&options, command, keyparm, facilitytime);
 
     endwin();
