@@ -51,7 +51,7 @@ extern int exitloop;
 extern int daemonized;
 
 void writetcplog(int logging, FILE * fd, struct tcptableent *entry,
-		 unsigned int pktlen, char *message);
+		 unsigned int pktlen, int mac, char *message);
 void write_tcp_unclosed(int logging, FILE * fd, struct tcptable *table);
 void write_timeout_log(int logging, FILE *logfile, struct tcptableent *tcpnode);
 void show_sort_statwin(WINDOW **statwin, PANEL **statpanel);
@@ -59,7 +59,7 @@ void show_sort_statwin(WINDOW **statwin, PANEL **statpanel);
 void rotate_ipmon_log()
 {
     rotate_flag = 1;
-    strcpy(target_logname, IPMONLOG);
+    strcpy(target_logname, current_logfile);
     signal(SIGUSR1, rotate_ipmon_log);
 }
 
@@ -68,10 +68,10 @@ void rotate_ipmon_log()
 void ipmonhelp()
 {
     move(LINES - 1, 1);
-    printkeyhelp("Up/Dn/PgUp/PgDn", "-scroll  ", stdscr);
+    printkeyhelp("Up/Dn/PgUp/PgDn", "-scroll  ", stdscr, HIGHATTR, STATUSBARATTR);
     move(LINES - 1, 43);
-    printkeyhelp("W", "-chg actv win  ", stdscr);
-    printkeyhelp("S", "-sort TCP  ", stdscr);
+    printkeyhelp("W", "-chg actv win  ", stdscr, HIGHATTR, STATUSBARATTR);
+    printkeyhelp("S", "-sort TCP  ", stdscr, HIGHATTR, STATUSBARATTR);
     stdexitkeyhelp();
 };
 
@@ -79,15 +79,16 @@ void uniq_help(int what)
 {
     move(LINES - 1, 25);
     if (!what)
-	printkeyhelp("M", "-more TCP info   ", stdscr);
+	printkeyhelp("M", "-more TCP info   ", stdscr, HIGHATTR, STATUSBARATTR);
     else
-	printkeyhelp("Lft/Rt", "-vtcl scrl  ", stdscr);
+	printkeyhelp("Lft/Rt", "-vtcl scrl  ", stdscr, HIGHATTR, STATUSBARATTR);
 }
 
 /* Mark general packet count indicators */
 
 void prepare_ip_statwin(WINDOW * win)
 {
+    wattrset(win, IPSTATLABELATTR);
     wmove(win, 0, 1);
     wprintw(win, "IP:");
     wmove(win, 0, 16 * COLS / 80);
@@ -131,6 +132,7 @@ void show_ip_stats(WINDOW * win, unsigned long long iptotal,
 		   unsigned long long icmptotal,
 		   unsigned long long noniptotal)
 {
+    wattrset(win, IPSTATATTR);
     wmove(win, 0, 6 * COLS / 80);
     printlargenum(iptotal, win);
     wmove(win, 0, 21 * COLS / 80);
@@ -217,8 +219,8 @@ void scrolllowerwin(struct othptable *table, int direction)
 		whline(table->borderwin, ACS_HLINE, 8);
 		table->htstat = NOHTIND;
 	    }
-	    printothpentry(table, table->lastvisible, table->oimaxy - 1, 0,
-			   (FILE *) NULL);
+	    printothpentry(table, table->lastvisible, table->oimaxy - 1, 
+	    		   0, (FILE *) NULL);
 	}
     } else {
 	if (table->firstvisible != table->head) {
@@ -231,8 +233,8 @@ void scrolllowerwin(struct othptable *table, int direction)
 		whline(table->borderwin, ACS_HLINE, 8);
 		table->htstat = NOHTIND;
 	    }
-	    printothpentry(table, table->firstvisible, 0, 0,
-			   (FILE *) NULL);
+	    printothpentry(table, table->firstvisible, 0,
+			   0, (FILE *) NULL);
 	}
     }
 }
@@ -265,17 +267,17 @@ void show_tcpsort_win(WINDOW ** win, PANEL ** panel)
     *win = newwin(9, 35, (LINES - 8) / 2, COLS - 40);
     *panel = new_panel(*win);
 
-    wattrset(*win, BOXATTR);
+    wattrset(*win, DLGBOXATTR);
     colorwin(*win);
     box(*win, ACS_VLINE, ACS_HLINE);
-    wattrset(*win, STDATTR);
+    wattrset(*win, DLGTEXTATTR);
     mvwprintw(*win, 2, 2, "Select sort criterion");
     wmove(*win, 4, 2);
-    printkeyhelp("P", " - sort by packet count", *win);
+    printkeyhelp("P", " - sort by packet count", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 5, 2);
-    printkeyhelp("B", " - sort by byte count", *win);
+    printkeyhelp("B", " - sort by byte count", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 6, 2);
-    printkeyhelp("Any other key", " - cancel sort", *win);
+    printkeyhelp("Any other key", " - cancel sort", *win, DLGHIGHATTR, DLGTEXTATTR);
     update_panels();
     doupdate();
 }
@@ -547,41 +549,43 @@ void ipmon(const struct OPTIONS *options, int filtered,
     struct isdntab isdntable;
 
     int p_sstat = 0, p_dstat = 0;	/* Reverse lookup statuses prior to */
-    /* reattempt in updateentry(). */
+    					/* reattempt in updateentry(). */
     int nifltok = 0;		/* Non-IP filter ok */
 
     int fragment = 0;		/* Set to 1 if not first fragment */
 
     int ch;
     int keymode = 0;
-    char msgstring[40];
+    char msgstring[80];
     int nomem = 0;
 
     struct promisc_states *promisc_list;
 
     int rvnfd = 0;
 
+    int instance_id;
+    
     /* 
      * Mark this instance of the traffic monitor
      */
 
-    if (!facility_active(IPMONIDFILE))
-	mark_facility(IPMONIDFILE, "IP traffic monitor");
+    if (!facility_active(IPMONIDFILE, ifptr))
+	mark_facility(IPMONIDFILE, "IP traffic monitor", ifptr);
     else {
-	write_error("IP Traffic Monitor active in another process",
-		    daemonized);
+        snprintf(msgstring, 80, "IP Traffic Monitor already listening on %s", gen_iface_msg(ifptr));
+	write_error(msgstring, daemonized);
 	return;
     }
 
     if (ifptr != NULL) {
 	if (!iface_supported(ifptr)) {
 	    err_iface_unsupported();
-	    unmark_facility(IPMONIDFILE);
+	    unmark_facility(IPMONIDFILE, ifptr);
 	    return;
 	}
 	if (!iface_up(ifptr)) {
 	    err_iface_down();
-	    unmark_facility(IPMONIDFILE);
+	    unmark_facility(IPMONIDFILE, ifptr);
 	    return;
 	}
     }
@@ -589,7 +593,7 @@ void ipmon(const struct OPTIONS *options, int filtered,
     open_socket(&fd);
 
     if (fd < 0) {
-	unmark_facility(IPMONIDFILE);
+	unmark_facility(IPMONIDFILE, ifptr);
 	return;
     }
 
@@ -601,10 +605,16 @@ void ipmon(const struct OPTIONS *options, int filtered,
 	}
     }
 
-    adjust_process_count(1);
+    /*
+     * Adjust instance counters
+     */
+     
+    adjust_instance_count(PROCCOUNTFILE, 1);
+    instance_id = adjust_instance_count(ITRAFMONCOUNTFILE, 1);
+    strncpy(active_facility_countfile, ITRAFMONCOUNTFILE, 64);
 
     init_tcp_table(&table);
-    init_othp_table(&othptbl);
+    init_othp_table(&othptbl, options->mac);
 
     if (options->revlook) {
 	if (checkrvnamed())
@@ -619,7 +629,7 @@ void ipmon(const struct OPTIONS *options, int filtered,
     uniq_help(0);
     statwin = newwin(1, COLS, LINES - 2, 0);
     statpanel = new_panel(statwin);
-    wattrset(statwin, FIELDATTR);
+    wattrset(statwin, IPSTATLABELATTR);
     wmove(statwin, 0, 0);
     sprintf(sp_buf, "%%%dc", COLS);
     wprintw(statwin, sp_buf, ' ');
@@ -637,9 +647,17 @@ void ipmon(const struct OPTIONS *options, int filtered,
      */
 
     bzero(&isdntable, sizeof(struct isdntab));
-
+    
+    if (logging) {
+        if (strcmp(current_logfile, "") == 0)
+            strncpy(current_logfile, gen_instance_logname(IPMONLOG, instance_id), 80);
+        
+        if (!daemonized)
+            input_logfile(current_logfile, &logging);
+    }
+    
     if (logging)
-	opentlog(&logfile, IPMONLOG);
+	opentlog(&logfile, current_logfile);
 
     if (logfile == NULL)
 	logging = 0;
@@ -648,8 +666,8 @@ void ipmon(const struct OPTIONS *options, int filtered,
 	signal(SIGUSR1, rotate_ipmon_log);
 
     rotate_flag = 0;
-    writelog(logging, logfile, "******** IP traffic monitor started");
-
+    writelog(logging, logfile, "******** IP traffic monitor started ********");
+   
     exitloop = 0;
     gettimeofday(&tv, NULL);
     starttime = timeint = closedint = tv.tv_sec;
@@ -717,7 +735,9 @@ void ipmon(const struct OPTIONS *options, int filtered,
 		case 'm':
 		case 'M':
 		    if (!curwin) {
-			mode = ~mode;
+			mode = (++mode) % 3;
+			if ((mode == 1) && (!options->mac))
+			    mode = 2;
 			refreshtcpwin(&table, screen_idx, mode);
 		    }
 		    break;
@@ -732,7 +752,7 @@ void ipmon(const struct OPTIONS *options, int filtered,
 		case 'c':
 		case 'C':
 		    flushclosedentries(&table, tcptm, &screen_idx,
-				       options->logging, logfile);
+				       logging, logfile);
 		    refreshtcpwin(&table, screen_idx, mode);
 		    break;
 		case 's':
@@ -799,7 +819,7 @@ void ipmon(const struct OPTIONS *options, int filtered,
 					     0, 0, NOT_IP,
 					     fromaddr.sll_protocol,
 					     linktype, (char *) tpacket,
-					     packet, readlen, ifname, 0, 0,
+					     (char *) packet, readlen, ifname, 0, 0,
 					     0, logging, logfile,
 					     options->servnames, 0,
 					     &nomem);
@@ -920,15 +940,6 @@ void ipmon(const struct OPTIONS *options, int filtered,
 		 */
 
 		if (tcpentry != NULL) {
-
-		    if ((tcpentry->pcount == 0) && (logging)) {
-			strcpy(msgstring, "first packet");
-			if (transpacket->syn)
-			    strcat(msgstring, " (SYN)");
-
-			writetcplog(logging, logfile,
-				    tcpentry, nbplen, msgstring);
-		    }
 		    /* 
 		     * Don't bother updating the entry if the connection
 		     * has been previously reset.  (Does this really
@@ -940,11 +951,28 @@ void ipmon(const struct OPTIONS *options, int filtered,
 			    p_sstat = tcpentry->s_fstat;
 			    p_dstat = tcpentry->d_fstat;
 			}
-			updateentry(&table, tcpentry, transpacket, nbplen,
+			updateentry(&table, tcpentry, transpacket, tpacket,
+			            linktype, nbplen,
 				    br, ippacket->frag_off, logging,
-				    options->revlook, rvnfd, logfile,
+				    options->mac, options->revlook, rvnfd, logfile,
 				    &nomem);
 
+			/*
+			 * Log first packet of a TCP connection except if
+			 * it's a RST, which was already logged earlier in
+			 * updateentry()
+			 */
+			 
+		        if ((tcpentry->pcount == 1) &&
+		           (!(tcpentry->stat & FLAG_RST)) && (logging)) {
+			    strcpy(msgstring, "first packet");
+			    if (transpacket->syn)
+			        strcat(msgstring, " (SYN)");
+
+			    writetcplog(logging, logfile,
+				    tcpentry, nbplen, options->mac, msgstring);
+		        }
+			
 			if ((options->revlook)
 			    && (((p_sstat != RESOLVED)
 				 && (tcpentry->s_fstat == RESOLVED))
@@ -1019,8 +1047,8 @@ void ipmon(const struct OPTIONS *options, int filtered,
 		    othpent =
 			add_othp_entry(&othptbl, &table, ippacket->saddr,
 				       ippacket->daddr, IS_IP,
-				       ippacket->protocol, 0,
-				       (char *) transpacket, (char *) NULL,
+				       ippacket->protocol, linktype,
+				       (char *) tpacket, (char *) transpacket,
 				       nbplen, ifname, options->revlook,
 				       rvnfd, tcptm, logging, logfile,
 				       options->servnames, fragment,
@@ -1053,7 +1081,7 @@ void ipmon(const struct OPTIONS *options, int filtered,
 	if ((options->closedint != 0) &&
 	    ((now - closedint) / 60 >= options->closedint)) {
 	    flushclosedentries(&table, tcptm, &screen_idx,
-			       options->logging, logfile);
+			       logging, logfile);
 	    refreshtcpwin(&table, screen_idx, mode);
 	    closedint = now;
 	}
@@ -1092,7 +1120,8 @@ void ipmon(const struct OPTIONS *options, int filtered,
 	}
     }
 
-    killrvnamed();
+    if (get_instance_count(ITRAFMONCOUNTFILE) <= 1)
+        killrvnamed();
 
     if (options->servnames)
 	endservent();
@@ -1105,7 +1134,8 @@ void ipmon(const struct OPTIONS *options, int filtered,
 	srpromisc(0, promisc_list);
 	destroy_promisc_list(&promisc_list);
     }
-    adjust_process_count(-1);
+    adjust_instance_count(PROCCOUNTFILE, -1);
+    adjust_instance_count(ITRAFMONCOUNTFILE, -1);
 
     del_panel(table.tcppanel);
     del_panel(table.borderpanel);
@@ -1126,9 +1156,11 @@ void ipmon(const struct OPTIONS *options, int filtered,
     destroy_isdn_table(&isdntable);
     writelog(logging, logfile,
 	     "******** IP traffic monitor stopped ********\n");
-    unmark_facility(IPMONIDFILE);
+    unmark_facility(IPMONIDFILE, ifptr);
     if (logfile != NULL)
 	fclose(logfile);
+	
+    strcpy(current_logfile, "");
 
     signal(SIGUSR1, SIG_DFL);
 
