@@ -41,7 +41,7 @@ details.
 
 void makeoptionmenu(struct MENU *menu)
 {
-    initmenu(menu, 21, 40, (LINES - 21) / 2, (COLS - 40) / 16);
+    initmenu(menu, 19, 40, (LINES - 19) / 2 - 1, (COLS - 40) / 16);
     additem(menu, " ^R^everse DNS lookups",
 	    "Toggles resolution of IP addresses into host names");
     additem(menu, " TCP/UDP ^s^ervice names",
@@ -54,15 +54,10 @@ void makeoptionmenu(struct MENU *menu)
 	    "Toggles logging of traffic to a data file");
     additem(menu, " Acti^v^ity mode",
 	    "Toggles activity indicators between kbits/s and kbytes/s");
+    additem(menu, " Source ^M^AC addrs in traffic monitor",
+            "Toggles display of source MAC addresses in the IP Traffic Monitor");
     additem(menu, NULL, NULL);
-    additem(menu, " TCP ^t^imeout...",
-	    "Determines how long TCP entries may remain idle");
-    additem(menu, " Logging ^i^nterval...",
-	    "Sets the time between loggings for interface, host, and service stats");
-    additem(menu, " Screen ^u^pdate interval...",
-	    "Sets the screen update interval in seconds (set to 0 for fastest updates)");
-    additem(menu, " TCP cl^o^sed/idle persistence...",
-	    "Determines how long closed/idle/reset entries stay onscreen");
+    additem(menu, " ^T^imers", "Configures timeouts and intervals");
     additem(menu, NULL, NULL);
     additem(menu, " ^A^dditional ports...",
 	    "Allows you to add port numbers higher than 1023 for the service stats");
@@ -77,6 +72,20 @@ void makeoptionmenu(struct MENU *menu)
     additem(menu, " E^x^it configuration", "Returns to main menu");
 }
 
+void maketimermenu(struct MENU *menu)
+{
+    initmenu(menu, 7, 35, (LINES - 19) / 2 + 7, (COLS - 35) / 2);
+    additem(menu, " TCP ^t^imeout...",
+	    "Determines how long TCP entries may remain idle");
+    additem(menu, " ^L^ogging interval...",
+	    "Sets the time between loggings for interface, host, and service stats");
+    additem(menu, " ^S^creen update interval...",
+	    "Sets the screen update interval in seconds (set to 0 for fastest updates)");
+    additem(menu, " TCP closed/idle ^p^ersistence...",
+	    "Determines how long closed/idle/reset entries stay onscreen");
+    additem(menu, " E^x^it menu", "Returns to the configuration menu");
+}
+
 void printoptonoff(unsigned int option, WINDOW * win)
 {
     if (option)
@@ -112,7 +121,12 @@ void indicatesetting(int row, struct OPTIONS *options, WINDOW * win)
 	    wprintw(win, " kbits/s");
 	else
 	    wprintw(win, "kbytes/s");
+        break;
+    case 7:
+        printoptonoff(options->mac, win);
+        break;
     }
+   
 }
 
 void saveoptions(struct OPTIONS *options)
@@ -143,6 +157,7 @@ void setdefaultopts(struct OPTIONS *options)
     options->color = 1;
     options->logging = 0;
     options->actmode = KBITS;
+    options->mac = 0;
     options->timeout = 15;
     options->logspan = 3600;
     options->updrate = 0;
@@ -168,17 +183,17 @@ void loadoptions(struct OPTIONS *options)
 void updatetimes(struct OPTIONS *options, WINDOW * win)
 {
     wattrset(win, HIGHATTR);
-    mvwprintw(win, 8, 25, "%3u mins", options->timeout);
-    mvwprintw(win, 9, 25, "%3u mins", options->logspan / 60);
-    mvwprintw(win, 10, 25, "%3u secs", options->updrate);
-    mvwprintw(win, 11, 25, "%3u mins", options->closedint);
+    mvwprintw(win, 9, 25, "%3u mins", options->timeout);
+    mvwprintw(win, 10, 25, "%3u mins", options->logspan / 60);
+    mvwprintw(win, 11, 25, "%3u secs", options->updrate);
+    mvwprintw(win, 12, 25, "%3u mins", options->closedint);
 }
 
 void showoptions(struct OPTIONS *options, WINDOW * win)
 {
     int i;
 
-    for (i = 1; i <= 6; i++)
+    for (i = 1; i <= 7; i++)
 	indicatesetting(i, options, win);
 
     updatetimes(options, win);
@@ -196,11 +211,11 @@ void settimeout(unsigned int *value, const char *units, int allow_zero,
     dlgwin = newwin(7, 40, (LINES - 7) / 2, (COLS - 40) / 4);
     dlgpanel = new_panel(dlgwin);
 
-    wattrset(dlgwin, BOXATTR);
+    wattrset(dlgwin, DLGBOXATTR);
     colorwin(dlgwin);
     box(dlgwin, ACS_VLINE, ACS_HLINE);
 
-    wattrset(dlgwin, STDATTR);
+    wattrset(dlgwin, DLGTEXTATTR);
     wmove(dlgwin, 2, 2);
     wprintw(dlgwin, "Enter value in %s", units);
     wmove(dlgwin, 5, 2);
@@ -233,10 +248,13 @@ void settimeout(unsigned int *value, const char *units, int allow_zero,
 void setoptions(struct OPTIONS *options, struct porttab **ports)
 {
     int row = 1;
+    int trow = 1;        /* row for timer submenu */
     int aborted;
     int resp;
 
     struct MENU menu;
+    struct MENU timermenu;
+    
     WINDOW *statwin;
     PANEL *statpanel;
 
@@ -246,27 +264,28 @@ void setoptions(struct OPTIONS *options, struct porttab **ports)
 	return;
     }
     makeoptionmenu(&menu);
-
-    statwin = newwin(13, 35, (LINES - 20) / 2, (COLS - 40) / 16 + 40);
+    
+    statwin = newwin(14, 35, (LINES - 19) / 2 - 1, (COLS - 40) / 16 + 40);
     statpanel = new_panel(statwin);
 
     wattrset(statwin, BOXATTR);
     colorwin(statwin);
     box(statwin, ACS_VLINE, ACS_HLINE);
-    wmove(statwin, 7, 1);
+    wmove(statwin, 8, 1);
     whline(statwin, ACS_HLINE, 33);
     mvwprintw(statwin, 0, 1, " Current Settings ");
     wattrset(statwin, STDATTR);
     mvwprintw(statwin, 1, 2, "Reverse DNS lookups:");
-    mvwprintw(statwin, 2, 2, "Service names: ");
-    mvwprintw(statwin, 3, 2, "Promiscuous: ");
-    mvwprintw(statwin, 4, 2, "Color: ");
-    mvwprintw(statwin, 5, 2, "Logging: ");
-    mvwprintw(statwin, 6, 2, "Activity mode: ");
-    mvwprintw(statwin, 8, 2, "TCP timeout:");
-    mvwprintw(statwin, 9, 2, "Log interval:");
-    mvwprintw(statwin, 10, 2, "Update interval:");
-    mvwprintw(statwin, 11, 2, "Closed/idle persist:");
+    mvwprintw(statwin, 2, 2, "Service names:");
+    mvwprintw(statwin, 3, 2, "Promiscuous:");
+    mvwprintw(statwin, 4, 2, "Color:");
+    mvwprintw(statwin, 5, 2, "Logging:");
+    mvwprintw(statwin, 6, 2, "Activity mode:");
+    mvwprintw(statwin, 7, 2, "MAC addresses:");
+    mvwprintw(statwin, 9, 2, "TCP timeout:");
+    mvwprintw(statwin, 10, 2, "Log interval:");
+    mvwprintw(statwin, 11, 2, "Update interval:");
+    mvwprintw(statwin, 12, 2, "Closed/idle persist:");
     showoptions(options, statwin);
 
     do {
@@ -292,47 +311,64 @@ void setoptions(struct OPTIONS *options, struct porttab **ports)
 	case 6:
 	    options->actmode = ~(options->actmode);
 	    break;
-	case 8:
-	    settimeout(&(options->timeout), "minutes", DONT_ALLOW_ZERO,
-		       &aborted);
-	    if (!aborted)
-		updatetimes(options, statwin);
+	case 7:
+	    options->mac = ~(options->mac);
 	    break;
 	case 9:
-	    settimeout((unsigned int *) &(options->logspan), "minutes",
-		       DONT_ALLOW_ZERO, &aborted);
-	    if (!aborted) {
-		options->logspan = options->logspan * 60;
-		updatetimes(options, statwin);
-	    }
-	    break;
-	case 10:
-	    settimeout(&options->updrate, "seconds", ALLOW_ZERO, &aborted);
-	    if (!aborted)
-		updatetimes(options, statwin);
+            maketimermenu(&timermenu);
+	    do {
+	        showmenu(&timermenu);
+	        operatemenu(&timermenu, &trow, &aborted);
+	        
+	        switch(trow) {
+	        case 1:
+	            settimeout(&(options->timeout), "minutes", DONT_ALLOW_ZERO,
+		           &aborted);
+	            if (!aborted)
+		        updatetimes(options, statwin);
+	            break;
+		case 2:
+	            settimeout((unsigned int *) &(options->logspan), "minutes",
+		               DONT_ALLOW_ZERO, &aborted);
+	            if (!aborted) {
+		        options->logspan = options->logspan * 60;
+		        updatetimes(options, statwin);
+	            }
+	            break;
+	        case 3:
+	            settimeout(&options->updrate, "seconds", ALLOW_ZERO, &aborted);
+	            if (!aborted)
+		        updatetimes(options, statwin);
+	            break;
+	        case 4:
+	            settimeout(&options->closedint, "minutes", ALLOW_ZERO,
+		               &aborted);
+	            if (!aborted)
+		        updatetimes(options, statwin);
+	            break;
+	        }
+	    } while (trow != 5);
+	    
+	    destroymenu(&timermenu);
+	    update_panels();
+	    doupdate();
 	    break;
 	case 11:
-	    settimeout(&options->closedint, "minutes", ALLOW_ZERO,
-		       &aborted);
-	    if (!aborted)
-		updatetimes(options, statwin);
-	    break;
-	case 13:
 	    addmoreports(ports);
 	    break;
-	case 14:
+	case 12:
 	    removeaport(ports);
 	    break;
-	case 16:
+	case 14:
 	    ethdescmgr(LINK_ETHERNET);
 	    break;
-	case 17:
+	case 15:
 	    ethdescmgr(LINK_FDDI);
 	    break;
 	}
 
 	indicatesetting(row, options, statwin);
-    } while (row != 19);
+    } while (row != 17);
 
     destroymenu(&menu);
     del_panel(statpanel);
