@@ -17,7 +17,7 @@ struct othpoptions {
     unsigned int filtercode;
 
     u_int16_t udp:1, icmp:1, ospf:1, igp:1, igmp:1, igrp:1, arp:1, rarp:1,
-     nonip:1, padding:7;
+     nonip:1, gre:1, unknip: 1, padding:5;
 };
 
 void othfilterselect(struct othpoptions *filter);
