@@ -38,7 +38,7 @@ void writeothplog(int logging, FILE * fd, char *protname,
 		  char *description, char *additional, int is_ip,
 		  int withmac, struct othptabent *entry);
 
-void init_othp_table(struct othptable *table)
+void init_othp_table(struct othptable *table, int mac)
 {
     unsigned int winht;
     unsigned int wintop;
@@ -69,6 +69,8 @@ void init_othp_table(struct othptable *table)
     stdwinset(table->othpwin);
     getmaxyx(table->borderwin, table->obmaxy, obmaxx);
     table->oimaxy = table->obmaxy - 2;
+    
+    table->mac = mac;
 }
 
 void process_dest_unreach(struct tcptable *table, char *packet,
@@ -127,38 +129,7 @@ struct othptabent *add_othp_entry(struct othptable *table,
     new_entry->is_ip = is_ip;
     new_entry->fragment = fragment;
 
-    if (is_ip) {
-	new_entry->saddr = isaddr.s_addr = saddr;
-	new_entry->daddr = idaddr.s_addr = daddr;
-
-	revname(rev_lookup, &isaddr, new_entry->s_fqdn, rvnfd);
-	revname(rev_lookup, &idaddr, new_entry->d_fqdn, rvnfd);
-
-	if (!fragment) {
-	    if (protocol == IPPROTO_ICMP) {
-		new_entry->un.icmp.type =
-		    ((struct icmphdr *) packet)->type;
-		new_entry->un.icmp.code =
-		    ((struct icmphdr *) packet)->code;
-	    } else if (protocol == IPPROTO_UDP) {
-		servlook(servnames, ((struct udphdr *) packet)->source,
-			 IPPROTO_UDP, new_entry->un.udp.s_sname, 10);
-		servlook(servnames, ((struct udphdr *) packet)->dest,
-			 IPPROTO_UDP, new_entry->un.udp.d_sname, 10);
-	    } else if (protocol == IPPROTO_OSPFIGP) {
-		new_entry->un.ospf.type =
-		    ((struct ospfhdr *) packet)->ospf_type;
-		new_entry->un.ospf.area =
-		    ntohl(((struct ospfhdr *) packet)->ospf_areaid.s_addr);
-		strcpy(new_entry->un.ospf.routerid,
-		       inet_ntoa(
-				 ((struct ospfhdr *)
-				  packet)->ospf_routerid));
-	    }
-	}
-    } else {
-	new_entry->linkproto = linkproto;
-
+    if ((table->mac) || (!is_ip)) {
 	if ((linkproto == LINK_ETHERNET) || (linkproto == LINK_PLIP)) {
 	    convmacaddr(((struct ethhdr *) packet)->h_source,
 			new_entry->smacaddr);
@@ -169,7 +140,41 @@ struct othptabent *add_othp_entry(struct othptable *table,
 			new_entry->smacaddr);
 	    convmacaddr(((struct fddihdr *) packet)->daddr,
 			new_entry->dmacaddr);
+        }
+    }
+        
+    if (is_ip) {
+	new_entry->saddr = isaddr.s_addr = saddr;
+	new_entry->daddr = idaddr.s_addr = daddr;
+
+	revname(rev_lookup, &isaddr, new_entry->s_fqdn, rvnfd);
+	revname(rev_lookup, &idaddr, new_entry->d_fqdn, rvnfd);
+
+	if (!fragment) {
+	    if (protocol == IPPROTO_ICMP) {
+		new_entry->un.icmp.type =
+		    ((struct icmphdr *) packet2)->type;
+		new_entry->un.icmp.code =
+		    ((struct icmphdr *) packet2)->code;
+	    } else if (protocol == IPPROTO_UDP) {
+		servlook(servnames, ((struct udphdr *) packet2)->source,
+			 IPPROTO_UDP, new_entry->un.udp.s_sname, 10);
+		servlook(servnames, ((struct udphdr *) packet2)->dest,
+			 IPPROTO_UDP, new_entry->un.udp.d_sname, 10);
+	    } else if (protocol == IPPROTO_OSPFIGP) {
+		new_entry->un.ospf.type =
+		    ((struct ospfhdr *) packet2)->ospf_type;
+		new_entry->un.ospf.area =
+		    ntohl(((struct ospfhdr *) packet2)->ospf_areaid.s_addr);
+		strcpy(new_entry->un.ospf.routerid,
+		       inet_ntoa(
+				 ((struct ospfhdr *)
+				  packet2)->ospf_routerid));
+	    }
 	}
+    } else {
+	new_entry->linkproto = linkproto;
+
 	if (protocol == ETH_P_ARP) {
 	    new_entry->un.arp.opcode = ((struct arp_hdr *) packet2)->ar_op;
 	    memcpy(&(new_entry->un.arp.src_ip_address),
@@ -269,7 +274,8 @@ char *packetlookup(unsigned int protocol)
 }
 
 void printothpentry(struct othptable *table, struct othptabent *entry,
-		    unsigned int target_row, int logging, FILE * logfile)
+		    unsigned int target_row, int logging,
+		    FILE * logfile)
 {
     char protname[SHORTSTRING_MAX];
     char description[SHORTSTRING_MAX];
@@ -286,8 +292,6 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 
     unsigned int unknown = 0;
 
-    int withmac = 0;
-
     sprintf(sp_buf, "%%%dc", COLS - 2);
 
     wmove(table->borderwin, table->obmaxy - 1, 1);
@@ -366,11 +370,10 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 		    entry->smacaddr, entry->dmacaddr, entry->iface);
 
 	    strcat(msgstring, scratchpad);
-	    withmac = 1;
 	}
 	startstr = msgstring + table->strindex;
 	waddnstr(table->othpwin, startstr, COLS - 4);
-	writeothplog(logging, logfile, protname, "", "", 0, withmac,
+	writeothplog(logging, logfile, protname, "", "", 0, 0,
 		     entry);
 	return;
     }
@@ -416,22 +419,22 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 	if (entry->protocol == IPPROTO_ICMP) {
 	    switch (entry->un.icmp.type) {
 	    case ICMP_ECHOREPLY:
-		strcpy(description, "echo reply");
+		strcpy(description, "echo rply");
 		break;
 	    case ICMP_ECHO:
-		strcpy(description, "echo request");
+		strcpy(description, "echo req");
 		break;
 	    case ICMP_DEST_UNREACH:
-		strcpy(description, "dest unreach");
+		strcpy(description, "dest unrch");
 		switch (entry->un.icmp.code) {
 		case ICMP_NET_UNREACH:
-		    strcpy(additional, "network");
+		    strcpy(additional, "ntwk");
 		    break;
 		case ICMP_HOST_UNREACH:
 		    strcpy(additional, "host");
 		    break;
 		case ICMP_PROT_UNREACH:
-		    strcpy(additional, "protocol");
+		    strcpy(additional, "proto");
 		    break;
 		case ICMP_PORT_UNREACH:
 		    strcpy(additional, "port");
@@ -440,7 +443,7 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 		    strcpy(additional, "DF set");
 		    break;
 		case ICMP_SR_FAILED:
-		    strcpy(additional, "src route failed");
+		    strcpy(additional, "src rte fail");
 		    break;
 		case ICMP_NET_UNKNOWN:
 		    strcpy(additional, "net unkn");
@@ -449,7 +452,7 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 		    strcpy(additional, "host unkn");
 		    break;
 		case ICMP_HOST_ISOLATED:
-		    strcpy(additional, "src isoltd");
+		    strcpy(additional, "src isltd");
 		    break;
 		case ICMP_NET_ANO:
 		    strcpy(additional, "net comm denied");
@@ -458,13 +461,13 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 		    strcpy(additional, "host comm denied");
 		    break;
 		case ICMP_NET_UNR_TOS:
-		    strcpy(additional, "net unreach for TOS");
+		    strcpy(additional, "net unrch for TOS");
 		    break;
 		case ICMP_HOST_UNR_TOS:
-		    strcpy(additional, "host unreach for TOS");
+		    strcpy(additional, "host unrch for TOS");
 		    break;
 		case ICMP_PKT_FILTERED:
-		    strcpy(additional, "pkt filtrd");
+		    strcpy(additional, "pkt fltrd");
 		    break;
 		case ICMP_PREC_VIOLATION:
 		    strcpy(additional, "prec violtn");
@@ -476,34 +479,34 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 
 		break;
 	    case ICMP_SOURCE_QUENCH:
-		strcpy(description, "source quench");
+		strcpy(description, "src qnch");
 		break;
 	    case ICMP_REDIRECT:
-		strcpy(description, "redirect");
+		strcpy(description, "redirct");
 		break;
 	    case ICMP_TIME_EXCEEDED:
-		strcpy(description, "time exceeded");
+		strcpy(description, "time excd");
 		break;
 	    case ICMP_PARAMETERPROB:
-		strcpy(description, "parameter problem");
+		strcpy(description, "param prob");
 		break;
 	    case ICMP_TIMESTAMP:
-		strcpy(description, "timestamp request");
+		strcpy(description, "timestmp req");
 		break;
 	    case ICMP_INFO_REQUEST:
-		strcpy(description, "information request");
+		strcpy(description, "info req");
 		break;
 	    case ICMP_INFO_REPLY:
-		strcpy(description, "information reply");
+		strcpy(description, "info rep");
 		break;
 	    case ICMP_ADDRESS:
-		strcpy(description, "address mask request");
+		strcpy(description, "addr mask req");
 		break;
 	    case ICMP_ADDRESSREPLY:
-		strcpy(description, "address mask reply");
+		strcpy(description, "addr mask rep");
 		break;
 	    default:
-		strcpy(description, "bad/unknown");
+		strcpy(description, "bad/unkn");
 		break;
 	    }
 
@@ -559,6 +562,11 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
     }
 
     strcat(msgstring, scratchpad);
+    
+    if (((entry->smacaddr)[0] != '\0') && (table->mac)) {
+        snprintf(scratchpad, MSGSTRING_MAX, " (src HWaddr %s)", entry->smacaddr); 
+        strcat(msgstring, scratchpad);
+    }
     strcat(msgstring, " on ");
     strcat(msgstring, entry->iface);
 
@@ -572,7 +580,7 @@ void printothpentry(struct othptable *table, struct othptabent *entry,
 
     if (logging)
 	writeothplog(logging, logfile, protname, description, additional,
-		     1, 0, entry);
+		     1, table->mac, entry);
 }
 
 void refresh_othwindow(struct othptable *table)
