@@ -20,6 +20,7 @@ details.
 
 ***/
 
+#include <stdlib.h>
 #include <netdb.h>
 #include <string.h>
 #include <sys/socket.h>
@@ -32,9 +33,23 @@ details.
 #include <errno.h>
 #include <curses.h>
 #include "deskman.h"
+#include "getpath.h"
 #include "rvnamed.h"
 
-int rvnamedactive()
+char revname_socket[80];
+
+char *gen_unix_sockname(void)
+{
+    static char scratch[80];
+    
+    srandom(time(NULL));
+    snprintf(scratch, 80, "%s-%lu%d%u", SOCKET_PREFIX,
+                                        time(NULL), getpid(), random()); 
+    
+    return scratch;
+}
+
+int rvnamedactive(void)
 {
     int fd;
     fd_set sockset;
@@ -44,11 +59,14 @@ int rvnamedactive()
     struct timeval tv;
     int fr;
     int br;
+    char unix_socket[80];
 
-    unlink(IPTCLSOCKNAME);
+    strncpy(unix_socket, get_path(T_WORKDIR, gen_unix_sockname()), 80);
+    unlink(unix_socket);
+    
     fd = socket(PF_UNIX, SOCK_DGRAM, 0);
     su.sun_family = AF_UNIX;
-    strcpy(su.sun_path, IPTCLSOCKNAME);
+    strcpy(su.sun_path, unix_socket);
     bind(fd, (struct sockaddr *) &su,
 	 sizeof(su.sun_family) + strlen(su.sun_path));
 
@@ -73,15 +91,17 @@ int rvnamedactive()
     if (sstat == 1) {
 	fr = sizeof(su.sun_family) + strlen(su.sun_path);
 	do {
-	    br =
-		recvfrom(fd, &rpkt, sizeof(struct rvn), 0,
+	    br = recvfrom(fd, &rpkt, sizeof(struct rvn), 0,
 			 (struct sockaddr *) &su, &fr);
 	} while ((br < 0) && (errno == EINTR));
 
 	if (br < 0)
 	    printipcerr();
     }
+    
     close(fd);
+    unlink(unix_socket);
+    
     if (sstat == 0)
 	return 0;
     else
@@ -113,11 +133,13 @@ void killrvnamed()
 void open_rvn_socket(int *fd)
 {
     struct sockaddr_un su;
-
-    unlink(IPTCLSOCKNAME);
+    
+    strncpy(revname_socket, get_path(T_WORKDIR, gen_unix_sockname()), 80);
+    unlink(revname_socket);
+    
     *fd = socket(PF_UNIX, SOCK_DGRAM, 0);
     su.sun_family = AF_UNIX;
-    strcpy(su.sun_path, IPTCLSOCKNAME);
+    strcpy(su.sun_path, revname_socket);
     bind(*fd, (struct sockaddr *) &su,
 	 sizeof(su.sun_family) + strlen(su.sun_path));
 }
@@ -126,7 +148,7 @@ void close_rvn_socket(int fd)
 {
     if (fd > 0) {
 	close(fd);
-	unlink(IPTCLSOCKNAME);
+	unlink(revname_socket);
     }
 }
 
