@@ -72,7 +72,7 @@ extern void writeutslog(struct portlistent *list, unsigned long nsecs,
 void rotate_serv_log()
 {
     rotate_flag = 1;
-    strcpy(target_logname, TCPUDPLOG);
+    strcpy(target_logname, current_logfile);
     signal(SIGUSR1, rotate_serv_log);
 }
 
@@ -488,28 +488,28 @@ void show_portsort_keywin(WINDOW ** win, PANEL ** panel)
     *win = newwin(14, 35, (LINES - 10) / 2, COLS - 40);
     *panel = new_panel(*win);
 
-    wattrset(*win, BOXATTR);
+    wattrset(*win, DLGBOXATTR);
     colorwin(*win);
     box(*win, ACS_VLINE, ACS_HLINE);
 
-    wattrset(*win, STDATTR);
+    wattrset(*win, DLGTEXTATTR);
     mvwprintw(*win, 2, 2, "Select display field to sort by");
     wmove(*win, 4, 2);
-    printkeyhelp("R", " - port number", *win);
+    printkeyhelp("R", " - port number", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 5, 2);
-    printkeyhelp("P", " - total packets", *win);
+    printkeyhelp("P", " - total packets", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 6, 2);
-    printkeyhelp("B", " - total bytes", *win);
+    printkeyhelp("B", " - total bytes", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 7, 2);
-    printkeyhelp("T", " - packets to", *win);
+    printkeyhelp("T", " - packets to", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 8, 2);
-    printkeyhelp("O", " - bytes to", *win);
+    printkeyhelp("O", " - bytes to", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 9, 2);
-    printkeyhelp("F", " - packets from", *win);
+    printkeyhelp("F", " - packets from", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 10, 2);
-    printkeyhelp("M", " - bytes from", *win);
+    printkeyhelp("M", " - bytes from", *win, DLGHIGHATTR, DLGTEXTATTR);
     wmove(*win, 11, 2);
-    printkeyhelp("Any other key", " - cancel sort", *win);
+    printkeyhelp("Any other key", " - cancel sort", *win, DLGHIGHATTR, DLGTEXTATTR);
     update_panels();
     doupdate();
 }
@@ -567,15 +567,17 @@ void servmon(char *ifname, struct porttab *ports,
     WINDOW *sortwin;
     PANEL *sortpanel;
 
+    char msgstring[80];
+    
     /*
      * Mark this facility
      */
 
-    if (!facility_active(TCPUDPIDFILE))
-	mark_facility(TCPUDPIDFILE, "TCP/UDP monitor");
+    if (!facility_active(TCPUDPIDFILE, ifname))
+	mark_facility(TCPUDPIDFILE, "TCP/UDP monitor", ifname);
     else {
-	write_error("TCP/UDP monitor already active in another process",
-		    daemonized);
+        snprintf(msgstring, 80, "TCP/UDP monitor already running on %s", ifname);
+	write_error(msgstring, daemonized);
 	return;
     }
 
@@ -583,17 +585,17 @@ void servmon(char *ifname, struct porttab *ports,
     open_socket(&fd);
 
     if (fd < 0) {
-	unmark_facility(TCPUDPIDFILE);
+	unmark_facility(TCPUDPIDFILE, ifname);
 	return;
     }
     if (!iface_supported(ifname)) {
 	err_iface_unsupported();
-	unmark_facility(TCPUDPIDFILE);
+	unmark_facility(TCPUDPIDFILE, ifname);
 	return;
     }
     if (!iface_up(ifname)) {
 	err_iface_down();
-	unmark_facility(TCPUDPIDFILE);
+	unmark_facility(TCPUDPIDFILE, ifname);
 	return;
     }
 
@@ -604,8 +606,9 @@ void servmon(char *ifname, struct porttab *ports,
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(1);
-
+    adjust_instance_count(PROCCOUNTFILE, 1);
+    active_facility_countfile[0] = '\0';
+    
     initportlist(&list);
 
     move(LINES - 1, 1);
@@ -620,7 +623,15 @@ void servmon(char *ifname, struct porttab *ports,
 	setservent(1);
 
     if (logging) {
-	opentlog(&logfile, TCPUDPLOG);
+        if (strcmp(current_logfile, "") == 0)
+            snprintf(current_logfile, 80, "%s-%s.log", TCPUDPLOG, ifname);
+	
+	if (!daemonized)
+	    input_logfile(current_logfile, &logging);
+    }
+    
+    if (logging) {
+	opentlog(&logfile, current_logfile);
 
 	if (logfile == NULL)
 	    logging = 0;
@@ -790,18 +801,19 @@ void servmon(char *ifname, struct porttab *ports,
 	destroy_promisc_list(&promisc_list);
     }
 
-    adjust_process_count(-1);
+    adjust_instance_count(PROCCOUNTFILE, -1);
 
     del_panel(list.panel);
     delwin(list.win);
     del_panel(list.borderpanel);
     delwin(list.borderwin);
-    unmark_facility(TCPUDPIDFILE);
+    unmark_facility(TCPUDPIDFILE, ifname);
     update_panels();
     doupdate();
     destroyportlist(&list);
     destroyfraglist();
     destroy_isdn_table(&isdntable);
+    strcpy(current_logfile, "");
 }
 
 void portdlg(unsigned int *port_min, int *port_max, int *aborted, int mode)
@@ -813,17 +825,16 @@ void portdlg(unsigned int *port_min, int *port_max, int *aborted, int mode)
 
     struct FIELDLIST list;
 
-    /* TODO? : Adjust values for !80 column displays */
     bw = newwin(14, 50, (LINES - 14) / 2, (COLS - 50) / 2 - 10);
     bp = new_panel(bw);
 
     win = newwin(12, 48, (LINES - 14) / 2 + 1, (COLS - 50) / 2 - 9);
     panel = new_panel(win);
 
-    wattrset(bw, BOXATTR);
+    wattrset(bw, DLGBOXATTR);
     box(bw, ACS_VLINE, ACS_HLINE);
 
-    wattrset(win, STDATTR);
+    wattrset(win, DLGTEXTATTR);
     colorwin(win);
     stdwinset(win);
     wtimeout(win, -1);
@@ -841,7 +852,7 @@ void portdlg(unsigned int *port_min, int *port_max, int *aborted, int mode)
     stdkeyhelp(win);
 
     initfields(&list, 1, 20, (LINES - 14) / 2 + 10, (COLS - 50) / 2 - 8);
-    wattrset(list.fieldwin, STDATTR);
+    wattrset(list.fieldwin, DLGTEXTATTR);
     mvwprintw(list.fieldwin, 0, 6, "to");
 
     addfield(&list, 5, 0, 0, "");
