@@ -30,8 +30,9 @@ details.
 unsigned int bmaxy = 0;
 unsigned int imaxy = 0;
 
+void convmacaddr(char *addr, char *result);
 void writetcplog(int logging, FILE * fd, struct tcptableent *entry,
-		 unsigned int pktlen, char *message);
+		 unsigned int pktlen, int mac, char *message);
 void write_timeout_log(int logging, FILE * logfile,
 		       struct tcptableent *tcpnode);
 
@@ -45,7 +46,9 @@ void setlabels(WINDOW * win, int mode)
 	wprintw(win, " Packets ");
 	wmove(win, 0, 59 * COLS / 80);
 	wprintw(win, " Bytes ");
-    } else {
+    } else if (mode == 1) {
+        mvwprintw(win, 0, 47 * COLS / 80, " Source MAC Addr ");
+    } else if (mode == 2) {
 	wmove(win, 0, 45 * COLS / 80);
 	wprintw(win, " Pkt Size ");
 	wmove(win, 0, 56 * COLS / 80);
@@ -71,6 +74,13 @@ unsigned int tcp_hash(unsigned long saddr, unsigned int sport,
 	     (2 * daddr) + dport) % ENTRIES_IN_HASH_TABLE);
 }
 
+void print_tcp_num_entries(struct tcptable *table)
+{
+    mvwprintw(table->borderwin, table->bmaxy - 1, 1, " TCP: %6u entries ",
+	      table->count);
+}
+
+
 void init_tcp_table(struct tcptable *table)
 {
     int i;
@@ -107,6 +117,7 @@ void init_tcp_table(struct tcptable *table)
 
     wtimeout(table->tcpscreen, -1);
     stdwinset(table->tcpscreen);
+    print_tcp_num_entries(table);
 
     /* Initialize hash table with dummy header cells */
 
@@ -191,12 +202,6 @@ void del_tcp_hash_node(struct tcptable *table, struct tcptableent *entry)
     free(ptmp);
 }
 
-void print_tcp_num_entries(struct tcptable *table)
-{
-    mvwprintw(table->borderwin, table->bmaxy - 1, 1, " TCP: %6u entries ",
-	      table->count);
-}
-
 /*
  * Add a new entry to the TCP screen table
  */
@@ -205,7 +210,8 @@ struct tcptableent *addentry(struct tcptable *table,
 			     unsigned long int saddr,
 			     unsigned long int daddr,
 			     unsigned int sport, unsigned int dport,
-			     int protocol, char *ifname, int rev_lookup,
+			     int protocol,  
+			     char *ifname, int rev_lookup,
 			     int rvnfd, int servnames, int *nomem)
 {
     struct tcptableent *new_entry;
@@ -320,6 +326,13 @@ struct tcptableent *addentry(struct tcptable *table,
 
     strcpy(new_entry->ifname, ifname);
     strcpy(new_entry->oth_connection->ifname, ifname);
+    
+    /*
+     * Zero out MAC address fields
+     */
+     
+    bzero(new_entry->smacaddr, 15);
+    bzero(new_entry->oth_connection->smacaddr, 15);
 
     /*
      * Set raw port numbers
@@ -328,7 +341,6 @@ struct tcptableent *addentry(struct tcptable *table,
     new_entry->sport = new_entry->oth_connection->dport = ntohs(sport);
     new_entry->dport = new_entry->oth_connection->sport = ntohs(dport);
 
-
     new_entry->stat = new_entry->oth_connection->stat = 0;
 
     new_entry->s_fstat = revname(rev_lookup, &(new_entry->saddr),
@@ -479,11 +491,13 @@ struct tcptableent *in_table(struct tcptable *table, unsigned long saddr,
  */
 
 void updateentry(struct tcptable *table, struct tcptableent *tableentry,
-		 struct tcphdr *transpacket, unsigned long packetlength,
+		 struct tcphdr *transpacket, char *packet, int linkproto,
+		 unsigned long packetlength,
 		 unsigned int bcount, unsigned int fragofs, int logging,
-		 int revlook, int rvnfd, FILE * logfile, int *nomem)
+		 int mac, int revlook, int rvnfd, FILE * logfile, int *nomem)
 {
     char msgstring[MSGSTRING_MAX];
+    char newmacaddr[15];
 
     if (tableentry->s_fstat != RESOLVED) {
 	tableentry->s_fstat = revname(revlook, &(tableentry->saddr),
@@ -501,6 +515,29 @@ void updateentry(struct tcptable *table, struct tcptableent *tableentry,
     tableentry->bcount += bcount;
     tableentry->psize = packetlength;
 
+    if (mac) {
+        bzero(newmacaddr, 15);
+    
+    	if ((linkproto == LINK_ETHERNET) || (linkproto == LINK_PLIP)) {
+	    convmacaddr(((struct ethhdr *) packet)->h_source,
+			newmacaddr);
+	} else if (linkproto == LINK_FDDI) {
+	    convmacaddr(((struct fddihdr *) packet)->saddr,
+			newmacaddr);
+        }
+        
+        if (tableentry->smacaddr[0] != '\0') {
+            if (strcmp(tableentry->smacaddr, newmacaddr) != 0) {
+                snprintf(msgstring, MSGSTRING_MAX, "TCP; %s; from %s:%s to %s:%s: new source MAC address %s (previously %s)",
+                    tableentry->ifname, tableentry->s_fqdn, tableentry->s_sname, tableentry->d_fqdn, tableentry->d_sname,
+                    newmacaddr, tableentry->smacaddr);
+                writelog(logging, logfile, msgstring);
+                strcpy(tableentry->smacaddr, newmacaddr);
+            }
+        } else
+            strcpy(tableentry->smacaddr, newmacaddr);
+    }
+    
     /*
      * If this is not the first TCP fragment, skip interpretation of the
      * TCP header.
@@ -548,7 +585,7 @@ void updateentry(struct tcptable *table, struct tcptableent *tableentry,
 
 	    if (logging) {
 		writetcplog(logging, logfile, tableentry,
-			    tableentry->psize, "FIN acknowleged");
+			    tableentry->psize, mac, "FIN acknowleged");
 	    }
 	}
     }
@@ -593,7 +630,7 @@ void updateentry(struct tcptable *table, struct tcptableent *tableentry,
 		    tableentry->pcount, tableentry->bcount);
 
 	    writetcplog(logging, logfile, tableentry, tableentry->psize,
-			msgstring);
+			mac, msgstring);
 	}
     }
     if (transpacket->rst) {
@@ -608,7 +645,7 @@ void updateentry(struct tcptable *table, struct tcptableent *tableentry,
 		    tableentry->oth_connection->pcount,
 		    tableentry->oth_connection->bcount);
 	    writetcplog(logging, logfile, tableentry, tableentry->psize,
-			msgstring);
+			mac, msgstring);
 	}
     }
     if (transpacket->psh)
@@ -711,7 +748,8 @@ void printentry(struct tcptable *table, struct tcptableent *tableentry,
      * on the value of mode.
      */
 
-    if (mode == 0) {
+    switch(mode) {
+    case 0:
 	wmove(table->tcpscreen, target_row, 47 * COLS / 80 - 2);
 	if (tableentry->partial)
 	    wprintw(table->tcpscreen, ">");
@@ -720,7 +758,15 @@ void printentry(struct tcptable *table, struct tcptableent *tableentry,
 	wprintw(table->tcpscreen, "%8u  ", tableentry->pcount);
 	wmove(table->tcpscreen, target_row, 59 * COLS / 80 - 4);
 	wprintw(table->tcpscreen, "%9u  ", tableentry->bcount);
-    } else {
+        break;
+    case 1:
+        wmove(table->tcpscreen, target_row, 50 * COLS / 80);
+        if (tableentry->smacaddr[0] == '\0')
+            wprintw(table->tcpscreen, "    N/A    ");
+        else
+            wprintw(table->tcpscreen, "%s", tableentry->smacaddr);
+        break;
+    case 2:
 	wmove(table->tcpscreen, target_row, 45 * COLS / 80 + 3);
 	wprintw(table->tcpscreen, "%5u  ", tableentry->psize);
 	wmove(table->tcpscreen, target_row, 56 * COLS / 80 - 1);
@@ -933,6 +979,9 @@ void flushclosedentries(struct tcptable *table, time_t tm,
 	    ptmp = ptmp->next_entry;
 	    del_tcp_hash_node(table, ctmp);
 	    destroy_tcp_entry(table, ctmp);
+	    
+	    if (idx < *screen_idx)
+	        (*screen_idx)--;
 	} else {
 	    if (idx == *screen_idx)
 		table->firstvisible = ptmp;
