@@ -19,13 +19,16 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <net/if_arp.h>
+#include <asm/types.h>
 #include <linux/if_packet.h>
 #include <linux/if_ether.h>
+#include <linux/if_fddi.h>
 #include <net/if.h>
 #include <netinet/ip.h>
 #include <netinet/udp.h>
 #include "servname.h"
 #include "tcphdr.h"
+#include "links.h"
 
 #define max(a, b) (( a > b) ? a : b)
 
@@ -48,6 +51,7 @@ struct tcptableent {
     int d_fstat;        
     unsigned int sport;
     unsigned int dport;
+    char smacaddr[15];
     char s_sname[11];           /* Service names, maxlen=10 */
     char d_sname[11];
     unsigned int protocol;
@@ -123,9 +127,10 @@ struct tcptableent *in_table(struct tcptable *table,
 			     int logging, FILE * logfile, int *nomem);
 
 void updateentry(struct tcptable *table, struct tcptableent *tableentry,
-		 struct tcphdr *transpacket, unsigned long packetlength,
+		 struct tcphdr *transpacket, char *packet, int linkproto,
+		 unsigned long packetlength,
 		 unsigned int bcount, unsigned int fragofs, int logging,
-		 int revlook, int rvnfd, FILE * logfile, int *nomem);
+		 int mac, int revlook, int rvnfd, FILE * logfile, int *nomem);
 
 void addtoclosedlist(struct tcptable *table, struct tcptableent *tableentry,
 		     int *nomem);
