@@ -73,7 +73,7 @@ void gethostparams(struct hostparams *hp, int *aborted,
     dlgwin = newwin(12, 80, (LINES - 12) / 2, (COLS - 80) / 2);
     dlgpanel = new_panel(dlgwin);
 
-    wattrset(dlgwin, BOXATTR);
+    wattrset(dlgwin, DLGBOXATTR);
     colorwin(dlgwin);
     box(dlgwin, ACS_VLINE, ACS_HLINE);
     wmove(dlgwin, 0, 26);
@@ -82,7 +82,7 @@ void gethostparams(struct hostparams *hp, int *aborted,
     wmove(dlgwin, 0, 52);
     wprintw(dlgwin, " Second ");
 
-    wattrset(dlgwin, STDATTR);
+    wattrset(dlgwin, DLGTEXTATTR);
     wmove(dlgwin, 2, 2);
     wprintw(dlgwin, "Host name/IP address:");
     wmove(dlgwin, 4, 2);
@@ -137,16 +137,16 @@ int mark_filter_change(int protocol)
     int resp;
 
     if (protocol == F_TCP) {
-	if (!facility_active(TCPFLTIDFILE))
-	    mark_facility(TCPFLTIDFILE, "TCP filter change");
+	if (!facility_active(TCPFLTIDFILE, ""))
+	    mark_facility(TCPFLTIDFILE, "TCP filter change", "");
 	else {
 	    errbox("TCP filter data file in use; try again later",
 		   ANYKEY_MSG, &resp);
 	    return 0;
 	}
     } else {
-	if (!facility_active(UDPFLTIDFILE))
-	    mark_facility(UDPFLTIDFILE, "UDP filter change");
+	if (!facility_active(UDPFLTIDFILE, ""))
+	    mark_facility(UDPFLTIDFILE, "UDP filter change", "");
 	else {
 	    errbox("UDP filter data file in use; try again later",
 		   ANYKEY_MSG, &resp);
@@ -159,9 +159,9 @@ int mark_filter_change(int protocol)
 void clear_flt_tag(int protocol)
 {
     if (protocol == F_TCP)
-	unlink(TCPFLTIDFILE);
+	unmark_facility(TCPFLTIDFILE, "");
     else
-	unlink(UDPFLTIDFILE);
+	unmark_facility(UDPFLTIDFILE, "");
 }
 
 void definefilter(int protocol, int *aborted)
