@@ -15,7 +15,7 @@ void savefilter(unsigned int protocol, char *filename, struct filterlist *fl);
 void destroyfilter(struct filterlist *fl);
 void pickafilter(struct ffnode *files, struct ffnode **fltfile, int *aborted);
 int utfilter(struct filterlist *fl, unsigned long source, unsigned long dest,
-	     unsigned int sport, unsigned int dport);
+	     unsigned int sport, unsigned int dport, unsigned int protocol);
 int mark_filter_change(int protocol);
 void listfileerr(int code);
 void clear_flt_tag(int protocol);
